<?php
/** 
*
* ucp.php [Čeština]
*
* @package language
* @version $Id: ucp.php 501 2010-02-28 07:46:24Z ameeck $
* @copyright (c)  2009 phpBB.cz
* @license http://opensource.org/licenses/gpl-license.php GNU Public License 
* Original copyright: (c) 2005 phpBB Group
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
   exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

// Privacy policy and T&C
$lang = array_merge($lang, array(
	'TERMS_OF_USE_CONTENT'	=> 'Svým přístupem na „%1$s“ souhlasíte s&nbsp;následujícími podmínkami. Pokud nesouhlasíte, neprodleně opusťte „%1$s“, nevstupujte na něj a nepoužívejte jej. Vyhrazujeme si právo tyto podmínky kdykoliv změnit a učiníme vše potřebné pro to, abychom vás o&nbsp;této změně informovali.  Přesto je rozumné tyto podmínky průběžně sledovat vzhledem k&nbsp;tomu, že používáním  „%1$s“ s&nbsp;nimi souhlasíte.<br />
	<br />
	Naše fóra beží na systému phpBB, což je řešení internetového fóra, které je vydané pod licencí „<a href="http://opensource.org/licenses/gpl-license.php">General Public License</a>“ a které je možno stáhnout z <a href="http://www.phpbb.com/">www.phpbb.com</a>. phpBB software pouze zprostředkovává internetové diskuze. Pro další informace o&nbsp;phpBB navštivte: <a href="http://www.phpbb.com/">http://www.phpbb.com/</a>.<br />
	<br />
	Zavazujete se nepřispívat na fórum pohoršujícím, hanlivým, nevhodným, vulgárním nebo jiným materiálem, který by mohl porušovat platné zákony ve vaší zemi, zákony v&nbsp;zemi, kde sídlí „%1$s“, nebo platné mezinárodní právo. Tato činnost může vést k&nbsp;okamžitému a trvalému vykázání z fóra a/nebo upozornění vašeho poskytovatele internetových služeb (ISP) na vaši činnost, pokud bude uznáno za nutné. IP adresy všech příspěvků jsou ukládány pro případné uplatnění těchto opatření. Souhlasíte s&nbsp;tím, že „%1$s“  má právo odstranit, upravit, přesunout nebo uzamknout jakékoliv téma nebo příspěvek, pokud to bude považovat za nutné. Jako uživatel souhlasíte se všemi údaji uloženými v&nbsp;databázi. Přestože „%1$s“ ani phpBB neposkytne tyto informace třetí straně nebo cizím osobám, nepřebírá „%1$s“ ani phpBB zodpovědnost za jakýkoliv pokus o&nbsp;vniknutí do systému, který by mohl vést ke kompromitaci těchto dat.
	',

	'PRIVACY_POLICY'		=> 'Toto prohlášení podrobně vysvětluje jak „%1$s“ a phpBB („phpBB software“, „www.phpbb.com“, „phpBB Group“) používá jakékoliv informace shromážděné během každé vaší návštěvy.<br />
	<br />
	Vaše osobní údaje jsou shromážděny dvěma způsoby. Prvním při vstupu na „%1$s“, kdy phpBB vytvoří několik cookies, což jsou malé textové soubory, které jsou stáhnuty a uloženy v&nbsp;dočasných souborech vašeho internetového prohlížeče. První dvě cookies obsahují jen uživatelské-id a anonymní identifikátor session, které je vám automaticky přiděleno phpBB softwarem. Třetí cookie se vytvoří, jakmile začnete procházet mezi tématy na „%1$s“, a je používána k&nbsp;ukládání informace, které téma jste již přečetli, což vede k&nbsp;snažšímu a pohodlnějšímu pohybu po fóru.<br />
	<br />
	Můžeme také vytvořit další cookies, které nepatří k&nbsp;phpBB software během procházení „%1$s“, ale tyto cookies jsou mimo rozsah tohoto dokumentu, který se zaobírá jen soubory, které vytvořilo phpBB. Druhá možnost jak můžeme shromažďovat vaše osobní údaje, je vaše odeslání těchto údajů nám. Toto může zahrnovat: odeslání příspěvků jako anonymní uživatel, registrace na „%1$s“ a odeslání příspěvků po vaší registrace, když jste přihlášeni.<br />
  <br />
  Váš účet bude přinejmenším obsahovat uživatelské jméno, osobní heslo, používané při přihlašování do vašeho účtu, a osobní, platnou e-mailovou adresu. Vaše osobní údaje pro váš účet na „%1$s“ jsou chráněny zákony o&nbsp;ochraně osobních údajů a dat, které jsou platné v&nbsp;zemi, ve které sídlíme. Jakékoliv jiné informace požadované od „%1$s“ kromě vašeho uživatelského jména, vašeho hesla a vašeho e-mailu při registraci, můžeme zvolit jako povinné nebo dobrovolné. Ve všech případech dostanete možnost rozhodnout, zda-li tyto informace budou veřejně zobrazitelné. Dále ve vašem účtu máte možnost zakázat nebo povolit zasílání automaticky vytvářených e-mailů phpBB softwarem na váš e-mail.<br />
  <br /> 
  Vaše heslo je zašifrováno (jednosměrný hash) pro zajištění jeho bezpečnosti. Přesto není doporučeno používat stejné heslo na dalších stránkách. Vaše heslo je prostředek k&nbsp;přístupu k&nbsp;vašemu účtu na „%1$s“, takže jej pečlivě uchovejte a v&nbsp;žádném případě nebude nikdo spojený s&nbsp;„%1$s“, phpBB nebo jiné, třetí strany, požadovat od vás vaše heslo. V případě, že byste zapomněli vaše heslo k&nbsp;vašemu účtu, můžete použít funkci „Zapomněl jsem své heslo“ poskytovanou phpBB softwarem. Tento proces po vás bude žádat zadaní vašeho uživatelského jména a vašeho e-mailu, poté phpBB software vygeneruje heslo nové a zašle vám ho, abyste se mohli přihlásit ke svému účtu.<br />
	',
));

// Common language entries
$lang = array_merge($lang, array(
	'ACCOUNT_ACTIVE'								=> 'Váš účet je nyní aktivní. Děkujeme za registraci.',
	'ACCOUNT_ACTIVE_ADMIN'					=> 'Váš účet je nyní aktivní.',
	'ACCOUNT_ACTIVE_PROFILE'				=> 'Váš účet byl reaktivován.',
	'ACCOUNT_ADDED'									=> 'Děkujeme za registraci, váš účet byl vytvořen. Můžete se přihlásit.',
	'ACCOUNT_COPPA'									=> 'Váš účet byl vytvořen. Před užíváním navštivte prosím vaši e-mailovou schránku.',
	'ACCOUNT_EMAIL_CHANGED'					=> 'Váš účet byl aktualizován. Fórum ale vyžaduje, abyste reaktivovali svůj účet po takovéto změně. Aktivační klíč byl zaslán na uvedenou adresu. Tam najdete další informace o&nbsp;tom, jak dále postupovat.',
	'ACCOUNT_EMAIL_CHANGED_ADMIN'		=> 'Váš účet byl aktualizován. Fórum ale vyžaduje reaktivaci účtu administrátory po změně e-mailové adresy. Byl jim zaslán e-mail a budete informováni, jakmile váš účet bude aktivní.',
	'ACCOUNT_INACTIVE'							=> 'Váš účet byl vytvořen. Toto fórum vyžaduje aktivaci účtu, aktivační e-mail vám byl zaslán na zadanou e-mailovou adresu.',
	'ACCOUNT_INACTIVE_ADMIN'				=> 'Váš účet byl vytvořen. Toto fórum vyžaduje aktivaci administrátorem. Budete informováni na zadané e-mailové adrese.',
	'ACTIVATION_EMAIL_SENT'					=> 'Aktivační e-mail byl zaslán.',
	'ACTIVATION_EMAIL_SENT_ADMIN'   => 'Aktivační e-mail byl zaslán na e-mailové adresy administrátorů.',

	'ADD'											=> 'Přidat',
	'ADD_BCC'									=> 'Přidat [skrytý]',
	'ADD_FOES'								=> 'Přidat mezi nepřátele',
	'ADD_FOES_EXPLAIN'				=> 'Zde můžete přidat několik uživatelů, každého na samostatný řádek.',
	'ADD_FOLDER'							=> 'Přidat adresář',
	'ADD_FRIENDS'							=> 'Přidat mezi přátele',
	'ADD_FRIENDS_EXPLAIN'			=> 'Zde můžete přidat několik uživatelů, každého na jinou řádku.',
	'ADD_NEW_RULE'						=> 'Přidat nové pravidlo',
	'ADD_RULE'								=> 'Přidat pravidlo',
	'ADD_TO'									=> 'Přidat',
	'ADD_USERS_UCP_EXPLAIN'		=> 'Odsud můžete přidat nové uživatele do skupiny. Můžete zvolit, jestli tato skupina bude jejich nová výchozí. Každé uživatelské jméno dejte na novou řádku.',
	'ADMIN_EMAIL'							=> 'Zasílat informace od administrátorů',
	'AGREE'										=> 'Souhlasím s&nbsp;těmito podmínkami',
	'ALLOW_PM'								=> 'Přijímat soukromé zprávy od uživatelů',
	'ALLOW_PM_EXPLAIN'				=> 'Zprávy od administrátorů a moderátorů budou přijímány.',
	'ALREADY_ACTIVATED'				=> 'Váš účet je již aktivován.',
	'ATTACHMENTS_EXPLAIN'			=> 'Toto je seznam příloh, které jste odeslali.',
	'ATTACHMENTS_DELETED'			=> 'Příloha byla odstraněna.',
	'ATTACHMENT_DELETED'			=> 'Přílohy byly odstraněny.',
	'AVATAR_CATEGORY'					=> 'Kategorie',
	'AVATAR_EXPLAIN'					=> 'Maximální rozměry; šířka: %1$d pixelů, výška: %2$d pixelů, velikost: %3$.2f KiB.',
	'AVATAR_FEATURES_DISABLED'		=> 'Avatary jsou v&nbsp;tuto chvíli na fóru vypnuté.',
	'AVATAR_GALLERY'							=> 'Místní galerie',
	'AVATAR_GENERAL_UPLOAD_ERROR'	=> 'Nelze nahrát obrázek do %s',
	'AVATAR_NOT_ALLOWED'					=> 'Váš avatar nebude zobrazen, protože jsou avatary celkově vypnutys.',
	'AVATAR_PAGE'									=> 'Stránka',
	'AVATAR_TYPE_NOT_ALLOWED'			=> 'Váš současný avatar nebude zobrazen, protože tento typ avatarů byl zakázán.',
	
	'BACK_TO_DRAFTS'				=> 'Zpět na koncepty',
	'BACK_TO_LOGIN'					=> 'Zpět na přihlašovací formulář',
	'BIRTHDAY'							=> 'Datum narození',
	'BIRTHDAY_EXPLAIN'			=> 'Nastavte datum vašeho narození.',
	'BOARD_DATE_FORMAT'			=> 'Formát data',
	'BOARD_DATE_FORMAT_EXPLAIN'	=> 'Syntaxe je shodná s&nbsp;PHP funkcí <a href="http://www.php.net/date" onclick="this.target=\'_blank\';" title="Otevřít v&nbsp;novém okně">date()</a>.',
	'BOARD_DST'							=> 'Platí letní čas',
	'BOARD_LANGUAGE'				=> 'Jazyk fóra',
	'BOARD_STYLE'						=> 'Vzhled fóra',
	'BOARD_TIMEZONE'				=> 'Časové pásmo',
	'BOOKMARKS'							=> 'Záložky',
	'BOOKMARKS_EXPLAIN'			=> 'Záložky si můžete ukládat pro budoucí použití. Zaškrtněte pole vedle záložky, kterou chcete smazat, a klikněte na <em>Odstranit označené záložky</em>.',
	'BOOKMARKS_DISABLED'		=> 'Na tomto fóru jsou záložky vypnuty',
	'BOOKMARKS_REMOVED'			=> 'Záložky byly smazány',
	
	'CANNOT_EDIT_MESSAGE_TIME'		=> 'Nemůžete již editovat tuto zprávu.',
	'CANNOT_MOVE_TO_SAME_FOLDER'	=> 'Zprávy nemohou být přesunuty do složky, kterou chcete odstranit.',
	'CANNOT_MOVE_FROM_SPECIAL'		=> 'Zprávy nemohou být přesunuty ze složky Odchozí.',
	'CANNOT_RENAME_FOLDER'				=> 'Tento adresář nemůže být přejmenován.',
	'CANNOT_REMOVE_FOLDER'				=> 'Tento adresář nemůže být smazán.',
	'CHANGE_DEFAULT_GROUP'				=> 'Změnit výchozí skupinu',
	'CHANGE_PASSWORD'			=> 'Změnit heslo',
	'CLICK_GOTO_FOLDER'			=> '%1$s Přejít do svého adresáře „%3$s“ %2$s',  
	'CLICK_RETURN_FOLDER'		=> '%1$s Vrátit se do adresáře „%3$s“ %2$s',
	'CONFIRMATION'				=> 'Potvrzení registrace',
	'CONFIRM_CHANGES'			=> 'Potvrdit změny',
	'CONFIRM_EMAIL'				=> 'Potvrzení e-mailové adresy',
	'CONFIRM_EMAIL_EXPLAIN'		=> 'Potvrďte vaši novou e-mailovou adresu.',
	'CONFIRM_EXPLAIN'			=> 'Jako obranu proti spam-botům vyžaduje administrátor používání ověřovacího kódu. Kód je zobrazen v&nbsp;obrázku níže. Pokud je kód nečitelný nebo zde není, kontaktujte %s Administrátora%s.',
	
	'VC_REFRESH'						=> 'Obnovit ověřovací kód',
	'VC_REFRESH_EXPLAIN'		=> 'Pokud nelze přečíst ověřovací kód, vygenerujte si nový kliknutím na tlačítko.',
   
	'CONFIRM_PASSWORD'			=> 'Potvrzení hesla',
	'CONFIRM_PASSWORD_EXPLAIN'	=> 'Potvrďte nové heslo.',
	'COPPA_BIRTHDAY'			=> 'Pro pokračovaní vyplňte prosím datum vašeho narození.',
	'COPPA_COMPLIANCE'			=> 'COPPA pravidla',
	'COPPA_EXPLAIN'				=> 'Vaše registrace vyžaduje potvrzení od starší osoby (rodičů). Pošlete e-mail s&nbsp;informacemi dané osobě.',
	'CREATE_FOLDER'				=> 'Přidat adresář…',
	'CURRENT_IMAGE'				=> 'Nynější obrázek',
	'CURRENT_PASSWORD'			=> 'Nynější heslo',
	'CURRENT_PASSWORD_EXPLAIN'	=> 'Pokud chcete změnit heslo nebo e-mailovou adresu, zadejte vaše nynější heslo.',
  'CUR_PASSWORD_EMPTY'		=> 'Nezadali jste současné heslo.',
	'CUR_PASSWORD_ERROR'		=> 'Zadali jste neplatné heslo.',
	'CUSTOM_DATEFORMAT'			=> 'Vlastní…',
		
	'DEFAULT_ACTION'			=> 'Výchozí akce',
	'DEFAULT_ACTION_EXPLAIN'	=> 'Tato akce je nastavena jako výchozí.',
	'DEFAULT_ADD_SIG'			=> 'Vždy připojit podpis',
	'DEFAULT_BBCODE'			=> 'Vždy povolit BBCode',
	'DEFAULT_NOTIFY'			=> 'Vždy mne upozornit, přijde-li odpověď',
	'DEFAULT_SMILIES'			=> 'Vždy povolit smajlíky',
	'DEFINED_RULES'				=> 'Určit pravidla',
	'DELETED_TOPIC'				=> 'Téma bylo smazáno',
	'DELETE_ATTACHMENT'			=> 'Smazat přílohu',
	'DELETE_ATTACHMENTS'		=> 'Smazat přílohy',
	'DELETE_ATTACHMENT_CONFIRM'	=> 'Opravdu chcete smazat tuto přílohu?',
	'DELETE_ATTACHMENTS_CONFIRM'=> 'Opravdu chcete smazat tyto přílohy?',
	'DELETE_AVATAR'				=> 'Smazat obrázek',
	'DELETE_COOKIES_CONFIRM'	=> 'Chcete smazat všechna cookies z vašeho disku uložená tímto fórem?',
	'DELETE_MARKED_PM'			=> 'Smazat všechny označené příspěvky',
	'DELETE_MARKED_PM_CONFIRM'	=> 'Opravdu chcete smazat všechny označené příspěvky?',
	'DELETE_OLDEST_MESSAGES'	=> 'Smazat staré příspěvky',
	'DELETE_MESSAGE'			=> 'Smazat zprávy',
	'DELETE_MESSAGE_CONFIRM'	=> 'Opravdu chcete smazat soukromé zprávy?',
	'DELETE_MESSAGES_IN_FOLDER'	=> 'Smazat adresář včetně všech zpráv',
	'DELETE_RULE'				=> 'Smazat pravidlo',
	'DELETE_RULE_CONFIRM'		=> 'Opravdu chcete smazat tuto podmínku?',
	'DEMOTE_SELECTED'			=> 'Zbavit se vedení skupiny',
	'DISABLE_CENSORS'			=> 'Zapnout cenzurování slov',
	'DISPLAY_GALLERY'			=> 'Zobrazit galerii',
	'DOMAIN_NO_MX_RECORD_EMAIL'	=> 'Zadaný e-mail nemá platný MX záznam.',
	'DOWNLOADS'					=> 'Stažené soubory',
	'DRAFTS_DELETED'			=> 'Všechny koncepty byly smazány.',
	'DRAFTS_EXPLAIN'			=> 'Zde můžete prohlížet, upravovat a mazat koncepty zpráv a příspěvků.',
	'DRAFT_UPDATED'				=> 'Koncept byl aktualizován.',
	
	'EDIT_DRAFT_EXPLAIN'		=> 'Zde můžete upravovat koncepty. Koncepty nemohou obsahovat ankety a přílohy.',
	'EMAIL_BANNED_EMAIL'		=> 'Zadaná e-mailová adresa je zabanovaná a nelze ji použít.',
	'EMAIL_INVALID_EMAIL'		=> 'Vámi zadaná e-mailová adresa není platná.',
	'EMAIL_REMIND'				=> 'Musíte uvést adresu nastavenou u&nbsp;vašeho účtu. Pokud jste ji neměnili, tak je to e-mailová adresa, se kterou jste se registrovali.',
	'EMAIL_TAKEN_EMAIL'			=> 'Vámi zadanou e-mailovou adresu má již registrovanou některý uživatel.',
	'EMPTY_DRAFT'				=> 'Musíte vyplnit zprávu pro potvrzení změn',
	'EMPTY_DRAFT_TITLE'			=> 'Musíte zadat název návrhu',
	'EXPORT_AS_XML'				=> 'Exportovat do XML',
	'EXPORT_AS_CSV'				=> 'Exportovat do CSV',
	'EXPORT_AS_CSV_EXCEL'		=> 'Exportovat do CSV (Excel)',
	'EXPORT_AS_TXT'				=> 'Exportovat do TXT',
	'EXPORT_AS_MSG'				=> 'Exportovat do MSG',
	'EXPORT_FOLDER'				=> 'Exportovat tuto složku',
	
	'FIELD_REQUIRED'			=> 'Políčko „%s“ musí být vyplněno.',
	'FIELD_TOO_SHORT'			=> 'Políčko „%1$s“ je příliš krátké, minimum je %2$d znaků.',
	'FIELD_TOO_LONG'			=> 'Políčko „%1$s“ je příliš dlouhé, maximum je %2$d znaků.',
	'FIELD_TOO_SMALL'			=> 'Hodnota „%1$s“ je příliš krátká, minimum je %2$d znaků.',
	'FIELD_TOO_LARGE'			=> 'Hodnota „%1$s“ je příliš dlouhá, maximum je %2$d znaků.',
	'FIELD_INVALID_CHARS_NUMBERS_ONLY'	=> 'Pole „%s“ obsahuje neplatné znaky, povoleny jsou jen čísla.',
	'FIELD_INVALID_CHARS_ALPHA_ONLY'	=> 'Pole „%s“ obsahuje neplatné znaky, povoleny jsou jen alfanumerické znaky.',
	'FIELD_INVALID_CHARS_SPACERS_ONLY'	=> 'Pole „%s“ obsahuje neplatné znaky, povoleny jsou jen alfanumerické znaky, mezery nebo znaky -+_[].',
	'FIELD_INVALID_DATE'		=> 'Pole „%s“ obsahuje neplatné datum.',
	'FIELD_INVALID_VALUE'				=> 'Pole „%s“ obsahuje neplatnou hodnotu.',  

	'FOE_MESSAGE'				=> 'Zpráva od nepřítele',
	'FOES_EXPLAIN'				=> 'Nepřátelé jsou standardně ignorováni. Zprávy od těchto uživatelů nejsou plně viditelné a SZ nejsou povoleny.',
	'FOES_UPDATED'				=> 'Seznam nepřátel byl aktualizován.',
	'FOLDER_ADDED'				=> 'Nový adresář byl přidán.',
	'FOLDER_MESSAGE_STATUS'		=> '%1$d z %2$d zpráv zaplněno',
	'FOLDER_NAME_EMPTY'			=> 'Musíte zadat název adresáře.',
	'FOLDER_NAME_EXIST'			=> 'Adresář <strong>%s</strong> již existuje',
	'FOLDER_OPTIONS'			=> 'Nastavení adresáře',
	'FOLDER_RENAMED'			=> 'Adresář byl přejmenován.',
	'FOLDER_REMOVED'			=> 'Adresář byl odstraněn.',
	'FOLDER_STATUS_MSG'			=> 'Adresář je z %1$d%% plný (Uloženo %2$d zpráv z %3$d možných).',
	'FORWARD_PM'				=> 'Přeposlat SZ',
	'FORCE_PASSWORD_EXPLAIN'	=> 'Než budete dále procházet toto fórum, prosím změňte si heslo.',
	'FRIEND_MESSAGE'			=> 'Zpráva od přítele',
	'FRIENDS'					=> 'Přátelé',
	'FRIENDS_EXPLAIN'			=> 'Mezi přáteli máte možnost rychlé komunikace.',
	'FRIENDS_OFFLINE'			=> 'Nepřipojen',
	'FRIENDS_ONLINE'			=> 'Připojen',
	'FRIENDS_UPDATED'			=> 'Seznam přátel byl aktualizován.',
  'FULL_FOLDER_OPTION_CHANGED'=> 'Nastavení přijímaní nových zpráv bylo změněno.',
	'FWD_ORIGINAL_MESSAGE'		=> '-------- Původní zpráva --------',
	'FWD_SUBJECT'				=> 'Předmět: %s',
	'FWD_DATE'					=> 'Datum: %s',
	'FWD_FROM'					=> 'Od: %s',
	'FWD_TO'					=> 'Komu: %s',

	'GLOBAL_ANNOUNCEMENT'		=> 'Globální oznámení',
	
	'HIDE_ONLINE'				=> 'Skrýt moji přítomnost na fóru',
  'HIDE_ONLINE_EXPLAIN'		=> 'Změna tohoto nastavení se projeví až po příštím přihlášení.',
	'HOLD_NEW_MESSAGES'			=> 'Nové zprávy jsou blokovány (nové zprávy budou přijaty až bude k&nbsp;dispozici dostatek místa).',
	'HOLD_NEW_MESSAGES_SHORT'	=> 'Blokovat nové zprávy',
	
	'IF_FOLDER_FULL'			=> 'Pokud je adresář plný',
	'IMPORTANT_NEWS'			=> 'Důležitá oznámení',
	'INVALID_USER_BIRTHDAY'			=> 'Zadané datum narozenin není platné datum.',
	'INVALID_CHARS_USERNAME'	=> 'Uživatelské jméno obsahuje nepovolené znaky.',
	'INVALID_CHARS_NEW_PASSWORD'=> 'Heslo neobsahuje požadované znaky.',
	'ITEMS_REQUIRED'			=> 'Položky označené takto * jsou povinné.',
	
	'JOIN_SELECTED'				=> 'Vstoupit do vybraných',
	
	'LANGUAGE'					=> 'Jazyk',
	'LINK_REMOTE_AVATAR'		=> 'Odkaz mimo tento web',
	'LINK_REMOTE_AVATAR_EXPLAIN'=> 'Napište adresu k&nbsp;obrázku.',
	'LINK_REMOTE_SIZE'			=> 'Rozměry obrázku',
	'LINK_REMOTE_SIZE_EXPLAIN'	=> 'Nastavte šířku a výšku, vynecháním budou nastaveny výchozí rozměry.',
	'LOGIN_EXPLAIN_UCP'			=> 'Prosím přihlaste se pro použití uživatelského panelu.',
	'LOGIN_REDIRECT'			=> 'Byli jste úspěšně přihlášeni, vítejte zpátky.',
	'LOGOUT_FAILED'				=> 'Nebyl jste odhlášen, protože dotaz nesouhlasil s&nbsp;ID vaší session. Kontaktuje administrátora fóra, pokud budou potíže přetrvávat.',
	'LOGOUT_REDIRECT'			=> 'Byli jste úspěšně odhlášeni, těšíme se na další návštěvu.',
	
	'MARK_IMPORTANT'			=> 'Označit/odznačit jako důležité',
	'MARKED_MESSAGE'			=> 'Označený příspěvek',
	'MAX_FOLDER_REACHED'		=> 'Byl dosažen maximální počet vlastních složek.',
  'MESSAGE_BY_AUTHOR'			=> 'od',
  'MESSAGE_COLOURS'			=> 'Barvy příspěvků',
	'MESSAGE_DELETED'			=> 'Zpráva byla odstraněna.',
	'MESSAGE_HISTORY'			=> 'Historie příspěvků',
	'MESSAGE_REMOVED_FROM_OUTBOX'	=> 'Zpráva byla smazána autorem dříve, než vám byla doručena.',
	'MESSAGE_SENT_ON'			=> 'v',
	'MESSAGE_STORED'			=> 'Zpráva byla odeslána.',
	'MESSAGE_TO'				=> 'Pro',
	'MESSAGES_DELETED'			=> 'Zprávy byly odstraněny.',
	'MOVE_DELETED_MESSAGES_TO'	=> 'Přesunout zprávy do adresáře',
	'MOVE_DOWN'					=> 'Přesunout dolů',
	'MOVE_MARKED_TO_FOLDER'		=> 'Přesunout označené do adresáře %s',
	'MOVE_PM_ERROR'				=> 'Nastal problém při přesouvání zpráv do nové složky, bylo přesunuto pouze %1d z %2d zpráv.',
	'MOVE_TO_FOLDER'			=> 'Přesunout do adresáře',
	'MOVE_UP'					=> 'Přesunout nahoru',

  'NEW_EMAIL_CONFIRM_EMPTY'		=> 'Nezadali jste podruhé vaší e-mailovou adresu pro její potvrzení.',	
	'NEW_EMAIL_ERROR'			=> 'E-mailová adresa nesouhlasí.',
	'NEW_FOLDER_NAME'			=> 'Název nového adresáře',
	'NEW_PASSWORD'				=> 'Heslo',
  'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'Nezadali jste podruhé vaše heslo pro jeho potvrzení.',
	'NEW_PASSWORD_ERROR'		=> 'Heslo musí odpovídat.',
	'NOTIFY_METHOD'				=> 'Způsob oznámení',
	'NOTIFY_METHOD_BOTH'		=> 'Oba způsoby',
	'NOTIFY_METHOD_EMAIL'		=> 'Pouze e-mail',
	'NOTIFY_METHOD_EXPLAIN'		=> 'Metoda pro posílání zpráv přes toto fórum.',
	'NOTIFY_METHOD_IM'			=> 'Pouze Jabber',
	'NOTIFY_ON_PM'				=> 'Zaslat upozornění pří příchozí soukromé zprávě',
	'NOT_ADDED_FRIENDS_ANONYMOUS'	=> 'Nemůžete přidat anonymního uživatele do seznamu přátel.',
	'NOT_ADDED_FRIENDS_FOES'	=> 'Nemůžete přidat uživatele do seznamu přátel, neboť ho máte v&nbsp;seznamu nepřátel',
	'NOT_ADDED_FRIENDS_BOTS'		=> 'Nelze přidávat boty do vašeho seznamu přítel.',
	'NOT_ADDED_FRIENDS_SELF'	=> 'Nemůžete se přidat k&nbsp;sobě do seznamu přátel',
	'NOT_ADDED_FOES_MOD_ADMIN'	=> 'Nemůžete přidat administrátora nebo moderátora do seznamu nepřátel.',
	'NOT_ADDED_FOES_ANONYMOUS'	=> 'Nemůžete přidat anonymního uživatele do seznamu nepřátel.',
	'NOT_ADDED_FOES_BOTS'			=> 'Nelze přidávat boty do vašeho seznamu nepřátel.',
	'NOT_ADDED_FOES_FRIENDS'	=> 'Nemůžete přidat uživatele do seznamu nepřátel, protože ho máte v&nbsp;seznamu přátel.',
	'NOT_ADDED_FOES_SELF'		=> 'Nemůžete se přidat k&nbsp;sobě do seznamu nepřátel.',
	'NOT_AGREE'					=> 'Nesouhlasím s&nbsp;těmito podmínkami',
	'NOT_ENOUGH_SPACE_FOLDER'	=> 'Adresář „%s“ je plný. Požadavek nebude dokončen.',
	'NOT_MOVED_MESSAGE'			=> 'Máte 1 blokovanou právu, protože adresář je plný.',
	'NOT_MOVED_MESSAGES'		=> 'Máte %d blokovaných zpráv, protože adresář je plný.',
	'NO_ACTION_MODE'			=> 'Akce nebyla specifikována',
	'NO_AUTHOR'					=> 'Nebyl definován autor pro tuto zprávu',
	'NO_AVATAR_CATEGORY'		=> 'Nic',
	
	'NO_AUTH_DELETE_MESSAGE'		=> 'Nemáte povolení mazat soukromé zprávy.',
	'NO_AUTH_EDIT_MESSAGE'			=> 'Nemáte povolení upravovat soukromé zprávy.',
	'NO_AUTH_FORWARD_MESSAGE'		=> 'Nemáte povolení přeposílat soukromé zprávy.',
	'NO_AUTH_GROUP_MESSAGE'			=> 'Nemáte povolení posílat soukromé zprávy skupinám.',
	'NO_AUTH_PASSWORD_REMINDER'      => 'Nemáte povolení zažádání o nové heslo.',
	'NO_AUTH_READ_HOLD_MESSAGE'      => 'Nemáte oprávnění vidět zprávy, které čekají ve frontě k doručení.',
	'NO_AUTH_READ_MESSAGE'			=> 'Nemáte povolení číst soukromé zprávy.',
	'NO_AUTH_READ_REMOVED_MESSAGE'	=> 'Nemůžete číst tuto zprávu, protože byla odstraněna autorem.',
	'NO_AUTH_SEND_MESSAGE'			=> 'Nemáte povolení odesílat soukromé zprávy.',
	'NO_AUTH_SIGNATURE'				=> 'Nemáte povolení nastavit si podpis.',
	
	'NO_BCC_RECIPIENT'			=> 'Nic',
	'NO_BOOKMARKS'				=> 'Nemáte žádné záložky',
	'NO_BOOKMARKS_SELECTED'		=> 'Nevybral jste žádné záložky',
	'NO_EDIT_READ_MESSAGE'		=> 'Soukromá zpráva nemůže být upravena, protože již byla přečtena.',
	'NO_EMAIL_USER'				=> 'Zadané uživatelské jméno nebo e-mail nebyly nalezeny.',
	'NO_FOES'					=> 'Nemáte vybrané žádné nepřátele',
	'NO_FRIENDS'				=> 'Nemáte vybrané žádné přátele',
	'NO_FRIENDS_OFFLINE'		=> 'Žádný přítel není nepřipojen',
	'NO_FRIENDS_ONLINE'			=> 'Žádný přítel není připojen',
	'NO_GROUP_SELECTED'			=> 'Žádná skupina není nadefinována',
	'NO_IMPORTANT_NEWS'			=> 'Nemůžete vložit oznámení',
	'NO_MESSAGE'				=> 'Soukromá zpráva nebyla nalezena',
	'NO_NEW_FOLDER_NAME'		=> 'Nespecifikoval jste nový název adresáře',
	'NO_NEWER_PM'				=> 'Žádné novější zprávy',
	'NO_OLDER_PM'				=> 'Žádné starší zprávy',
	'NO_PASSWORD_SUPPLIED'		=> 'Nelze se přihlásit bez hesla.',
	'NO_RECIPIENT'				=> 'Nebyl vybrán příjemce',
	'NO_RULES_DEFINED'			=> 'Žádná pravidla nejsou definována.',
	'NO_SAVED_DRAFTS'			=> 'Žádné uložené zprávy (příspěvky)',
	'NO_TO_RECIPIENT'			=> 'Nic',
	'NO_WATCHED_FORUMS'			=> 'Nesledujete žádná fóra.',
	'NO_WATCHED_SELECTED'      => 'Nevybrali jste si žádné sledované téma nebo fórum.',
	'NO_WATCHED_TOPICS'			=> 'Nesledujete žádná témata.',

	'PASS_TYPE_ALPHA_EXPLAIN'	=> 'Heslo musí mít %1$d až %2$d znaků a musí obsahovat kombinaci malých a velkých písmen a musí obsahovat čísla.',
	'PASS_TYPE_ANY_EXPLAIN'		=> 'Musí mít %1$d až %2$d znaků.',
	'PASS_TYPE_CASE_EXPLAIN'	=> 'Heslo musí mít %1$d až %2$d znaků dlouhé a musí být namixované.',
	'PASS_TYPE_SYMBOL_EXPLAIN'	=> 'Heslo musí mít %1$d až %2$d znaků dlouhé a musí obsahovat symboly',
	'PASSWORD'					=> 'Heslo',
	'PASSWORD_ACTIVATED'		=> 'Vaše nové heslo bylo aktivováno',
	'PASSWORD_UPDATED'			=> 'Na váš e-mail bylo posláno nově vygenerované heslo.',
	'PERMISSIONS_RESTORED'		=> 'Původní oprávnění byla načtena.',
	'PERMISSIONS_TRANSFERRED'	=> 'Pravomoci od <strong>%s</strong> byly úspěšně přeneseny. Nyní si můžete prohlížet fórum s&nbsp;oprávněními uživatele.<br />Berte na vědomí, že nebyla přenesena oprávnění administrátora. Můžete se kdykoliv vrátit k&nbsp;původním právům.',
	'PM_DISABLED'				=> 'Soukromé zprávy na tomto fóru jsou vypnuty',
	'PM_FROM'					=> 'Od',
	'PM_FROM_REMOVED_AUTHOR'	=> 'Tato zpráva byla zaslána uživatelem, který už není registrován.',
	'PM_ICON'					=> 'Ikona zprávy',
	'PM_INBOX'					=> 'Příchozí',
	'PM_NO_USERS'				=> 'Zadaní uživatelé neexistují.',
	'PM_OUTBOX'					=> 'Odeslané (nepřečtené)',
	'PM_SENTBOX'				=> 'Odeslané',
	'PM_SUBJECT'				=> 'Předmět zprávy',
	'PM_TO'						=> 'Příjemci:',
	'PM_USERS_REMOVED_NO_PM'	=> 'Někteří uživatele nemohli být přidáni, protože mají zakázané přijímaní Soukromých zpráv.',
	'POPUP_ON_PM'				=> 'Zobrazit popup okno při nové soukromé zprávě',
	'POST_EDIT_PM'				=> 'Upravit zprávu',
	'POST_FORWARD_PM'			=> 'Přeposlat zprávu',
	'POST_NEW_PM'				=> 'Odeslat zprávu',
	'POST_PM_LOCKED'			=> 'Soukromé zprávy jsou zamknuty.',
	'POST_PM_POST'				=> 'Citovat zprávu',
	'POST_QUOTE_PM'				=> 'Citovat příspěvek',
	'POST_REPLY_PM'				=> 'Odpovědět na zprávu',
	'PRINT_PM'					=> 'Vytisknout',
	'PREFERENCES_UPDATED'		=> 'Vaše nastavení bylo aktualizováno.',
	'PROFILE_INFO_NOTICE'		=> 'Prosím vyplňte informace dostupné ostatním uživatelům. Políčka s&nbsp;* musí být vyplněna.',
	'PROFILE_UPDATED'			=> 'Váš profil byl aktualizován.',
	
	'RECIPIENT'					=> 'Příjemce',
	'RECIPIENTS'				=> 'Příjemci',
	'REGISTRATION'				=> 'Registrace',
	'RELEASE_MESSAGES'			=> '%sUvolnění všech zpráv%s',
	'REMOVE_ADDRESS'			=> 'Smazat adresu',
	'REMOVE_SELECTED_BOOKMARKS'	=> 'Smazat vybrané záložky',
	'REMOVE_SELECTED_BOOKMARKS_CONFIRM'	=> 'Opravdu chcete smazat všechny vybrané záložky?',
	'REMOVE_BOOKMARK_MARKED'	=> 'Smazat označené záložky',
	'REMOVE_FOLDER'				=> 'Smazat adresář',
	'REMOVE_FOLDER_CONFIRM'		=> 'Opravdu chcete smazat tento adresář?',
	'RENAME'					=> 'Přejmenovat',
	'RENAME_FOLDER'				=> 'Přejmenovat adresář',
	'REPLIED_MESSAGE'			=> 'Odpověď',
	'REPLY_TO_ALL'						=> 'Odpovědět odesílateli a všem adresátům',
	'REPORT_PM'							=> 'Nahlásit soukromou zprávu',
	'RESIGN_SELECTED'			=> 'Vystoupit z vybraných',
	'RETURN_FOLDER'				=> '%1$s Vrátit se do předchozí složky%2$s',
	'RETURN_UCP'				=> '%s Vrátit se do Uživatelského panelu%s',
	'RULE_ADDED'				=> 'Pravidlo bylo přidáno.',
	'RULE_ALREADY_DEFINED'		=> 'Pravidlo již existuje.',
	'RULE_DELETED'				=> 'Pravidlo bylo vymazáno.',
	'RULE_NOT_DEFINED'			=> 'Pravidlo není správně definováno.',
	'RULE_REMOVED_MESSAGE'				=> 'Jedna soukromá zpráva byla odstraněna filtrem soukromých zpráv.',
	'RULE_REMOVED_MESSAGES'				=> '%d soukromých zpráv byla odstraněna filtrem soukromých zpráv.',
	
	'SAME_PASSWORD_ERROR'		=> 'Nové heslo je stejné jako staré',
	'SEARCH_YOUR_POSTS'			=> 'Zobrazit vaše příspěvky',
	'SEND_PASSWORD'				=> 'Odeslat heslo',
	'SENT_AT'					=> 'Odesláno',
	'SHOW_EMAIL'				=> 'Uživatelé mi mohou posílat zprávy přes toto fórum',
	'SIGNATURE_EXPLAIN'			=> 'Zde můžete editovat zobrazovaný text. <br><br>Limit je %d znaků.',
	'SIGNATURE_PREVIEW'			=> 'Podpis zobrazovaný pod příspěvky.',
	'SIGNATURE_TOO_LONG'		=> 'Váš podpis je příliš dlouhý.',
	'SORT'						=> 'Seřadit',
	'SORT_COMMENT'				=> 'Komentáře',
	'SORT_DOWNLOADS'			=> 'Počtu stažení',
	'SORT_EXTENSION'			=> 'Přípony',
	'SORT_FILENAME'				=> 'Názvu souboru',
	'SORT_POST_TIME'			=> 'Času odeslání',
	'SORT_SIZE'					=> 'Velikosti',
	
	'TIMEZONE'						=> 'Časová zóna',
	'TO'									=> 'Komu',
	'TOO_MANY_RECIPIENTS'	=> 'Pokusili jste se odeslat zprávu příliš mnoha příjemcům.',
	'TOO_MANY_REGISTERS'	=> 'Překročil jste limit pokusů o&nbsp;registraci. Prosím, zkuste to později.',
	
	'UCP'									=> 'Uživatelský panel',
	'UCP_ACTIVATE'				=> 'Účet byl aktivován',
	'UCP_ADMIN_ACTIVATE'	=> 'Musíte počkat na aktivaci účtu administrátorem.',
	'UCP_AIM'							=> 'AOL Instant Messenger',
	'UCP_ATTACHMENTS'			=> 'Přílohy',
	'UCP_COPPA_BEFORE'		=> 'Před %s',
	'UCP_COPPA_ON_AFTER'	=> 'Po %s',
	'UCP_EMAIL_ACTIVATE'	=> 'Zadejte správný e-mail, neboť vám na něj v brzké době přijde aktivační odkaz.',
	'UCP_ICQ'							=> 'ICQ číslo',
	'UCP_JABBER'					=> 'Jabber adresa',
	
	'UCP_MAIN'							=> 'Přehled',
	'UCP_MAIN_ATTACHMENTS'	=> 'Přílohy',
	'UCP_MAIN_BOOKMARKS'		=> 'Záložky',
	'UCP_MAIN_DRAFTS'				=> 'Koncepty příspěvků',
	'UCP_MAIN_FRONT'				=> 'Přehled',
	'UCP_MAIN_SUBSCRIBED'		=> 'Sledování',
	
	'UCP_MSNM'						=> 'Windows Live Messenger',
	'UCP_NO_ATTACHMENTS'	=> 'Neodeslal jste žádnou přílohu',
	
	'UCP_PREFS'						=> 'Nastavení',
	'UCP_PREFS_PERSONAL'	=> 'Osobní nastavení',
	'UCP_PREFS_POST'			=> 'Odesílání příspěvků',
	'UCP_PREFS_VIEW'			=> 'Prohlížení příspěvků',
	
	'UCP_PM'							=> 'Soukromé zprávy',
	'UCP_PM_COMPOSE'			=> 'Napsat zprávu',
	'UCP_PM_DRAFTS'				=> 'Koncepty',
	'UCP_PM_OPTIONS'			=> 'Nastavení uložených zpráv a pravidel',
	'UCP_PM_POPUP'				=> 'Soukromé zprávy',
	'UCP_PM_POPUP_TITLE'	=> 'Popup okno u&nbsp;soukromých zpráv',
	'UCP_PM_UNREAD'				=> 'Nepřečtené zprávy',
	'UCP_PM_VIEW'					=> 'Zobrazit zprávy',
	
	'UCP_PROFILE'								=> 'Profil',
	'UCP_PROFILE_AVATAR'				=> 'Avatar',
	'UCP_PROFILE_PROFILE_INFO'	=> 'Podrobnosti',
	'UCP_PROFILE_REG_DETAILS'		=> 'Registrační údaje',
	'UCP_PROFILE_SIGNATURE'			=> 'Podpis',
	
	'UCP_USERGROUPS'					=> 'Skupiny',
	'UCP_USERGROUPS_MEMBER'		=> 'Členství',
	'UCP_USERGROUPS_MANAGE'		=> 'Správce skupin',
	
	'UCP_REGISTER_DISABLE'		=> 'Nemůžete vytvořit další účet.',
	'UCP_REMIND'							=> 'Poslat heslo',
	'UCP_RESEND'							=> 'Poslat aktivační e-mail',
	'UCP_WELCOME'							=> 'Vítejte v&nbsp;Uživatelském panelu. Můžete zde prohlížet a upravovat svůj profil, nastavení, sledování fór a témat. Můžete také posílat soukromé zprávy (pokud je povoleno).<br> Prosím přečtěte si některá oznámení, než budete pokračovat.',
	'UCP_YIM'									=> 'Yahoo Messenger',
	'UCP_ZEBRA'								=> 'Přátelé a nepřátelé',
	'UCP_ZEBRA_FOES'					=> 'Nepřátelé',
	'UCP_ZEBRA_FRIENDS'				=> 'Přátelé',
	'UNDISCLOSED_RECIPIENT'			=> 'Adresát neuveden',
	'UNKNOWN_FOLDER'					=> 'Neznámý adresář',
	'UNWATCH_MARKED'					=> 'Odstranit sledování',
	'UPLOAD_AVATAR_FILE'			=> 'Nahrát z vašeho počítače',
	'UPLOAD_AVATAR_URL'				=> 'Nahrát z odkazu',
	'UPLOAD_AVATAR_URL_EXPLAIN'						=> 'Zde napište odkaz na obrázek.',
	'USERNAME_ALPHA_ONLY_EXPLAIN'					=> 'Uživatelské jméno musí mít %1$d až %2$d znaků a můžete použít pouze alfanumerické znaky.',
	'USERNAME_ALPHA_SPACERS_EXPLAIN'			=> 'Uživatelské jméno musí mít %1$d až %2$d znaků a použít alfanumerické znaky, mezery nebo znaky -+_[].',
	'USERNAME_ASCII_EXPLAIN'							=> 'Uživatelské jméno musí mít %1$d až %2$d znaků a může se skládat jen z ASCII znaků',
	'USERNAME_LETTER_NUM_EXPLAIN'					=> 'Uživatelské jméno musí mít %1$d až %2$d znaků a může se skládat jen z písmen a čísel',
	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'	=> 'Uživatelské jméno musí mít %1$d až %2$d znaků a používat písmena, čísla, mezery nebo znaky -+_[].',
	'USERNAME_CHARS_ANY_EXPLAIN'					=> 'Uživatelské jméno musí mít %1$d až %2$d znaků.',
	'USERNAME_TAKEN_USERNAME'							=> 'Vámi zadané uživ. jméno je již použito, prosím vyberte si jiné.',
	'USERNAME_DISALLOWED_USERNAME'				=> 'Uživatelské jméno, které jste zadal, je zabanováno.',
	'USER_NOT_FOUND_OR_INACTIVE'					=> 'Zadaná uživatelská jména nebyla nalezena nebo to nejsou aktivní uživatelé.',
	
	'VIEW_AVATARS'				=> 'Zobrazovat obrázky uživatelů',
	'VIEW_EDIT'						=> 'Zobrazit/Upravit',
	'VIEW_FLASH'					=> 'Zobrazovat Flash animace',
	'VIEW_IMAGES'					=> 'Zobrazovat obrázky v&nbsp;příspěvcích',
	'VIEW_NEXT_HISTORY'		=> 'Další SZ v&nbsp;historii',
	'VIEW_NEXT_PM'				=> 'Další SZ',
	'VIEW_PM'							=> 'Zobrazit zprávu',
	'VIEW_PM_INFO'				=> 'Detaily zprávy',
	'VIEW_PM_MESSAGE'			=> '1 zpráva',
	'VIEW_PM_MESSAGES'		=> '%d zpráv',
	'VIEW_PREVIOUS_HISTORY'		=> 'Předchozí SZ v&nbsp;historii',
	'VIEW_PREVIOUS_PM'		=> 'Předchozí SZ',
	'VIEW_SIGS'						=> 'Zobrazovat podpisy',
	'VIEW_SMILIES'				=> 'Zobrazovat smajlíky',
	'VIEW_TOPICS_DAYS'		=> 'Zobrazit témata za předchozí',
	'VIEW_TOPICS_DIR'			=> 'Seřadit témata',
	'VIEW_TOPICS_KEY'			=> 'Seřadit témata podle',
	'VIEW_POSTS_DAYS'			=> 'Zobrazit příspěvky za předchozí',
	'VIEW_POSTS_DIR'			=> 'Seřadit příspěvky',
	'VIEW_POSTS_KEY'			=> 'Seřadit příspěvky podle',
	
	'WATCHED_EXPLAIN'			=> 'Pokud označíte téma jako sledované, bude vám na e-mail chodit upozornění o&nbsp;novém příspěvku. Toto můžete zrušit kliknutím na <em>Nesledovat téma</em>',
	'WATCHED_FORUMS'			=> 'Sledovaná fóra',
	'WATCHED_TOPICS'			=> 'Sledovaná témata',
	'WRONG_ACTIVATION'		=> 'Klávesa pro aktivaci je nesprávná',
	
	'YOUR_DETAILS'					=> 'Vaše aktivita',
	'YOUR_FOES'							=> 'Vaši nepřátelé',
	'YOUR_FOES_EXPLAIN'			=> 'Chcete-li smazat nepřátele ze seznamu, vyberte je a stiskněte Odeslat.',
	'YOUR_FRIENDS'					=> 'Vaši přátelé',
	'YOUR_FRIENDS_EXPLAIN'	=> 'Chcete-li smazat přátele ze seznamu, vyberte je a stiskněte potvrdit.',
	'YOUR_WARNINGS'					=> 'Vaše varování',

	'PM_ACTION'	=> array(
		'PLACE_INTO_FOLDER'	=> 'Umístit do adresáře',
		'MARK_AS_READ'			=> 'Označit jako přečtenou',
		'MARK_AS_IMPORTANT'	=> 'Označit zprávu',
		'DELETE_MESSAGE'		=> 'Smazat zprávu',
	),
    'PM_CHECK' => array(
			'SUBJECT'	=> 'Předmět',
			'SENDER'	=> 'Odesílatel',
			'MESSAGE'	=> 'Zpráva',
			'STATUS'	=> 'Typ zprávy',
			'TO'			=> 'Komu:',
	),
    'PM_RULE' => array(
			'IS_LIKE'			=> 'obsahuje',
			'IS_NOT_LIKE'	=> 'neobsahuje',
			'IS'					=> 'je',
			'IS_NOT'			=> 'není',
			'BEGINS_WITH'	=> 'začíná',
			'ENDS_WITH'		=> 'končí',
			'IS_FRIEND'		=> 'je přítel',
			'IS_FOE'			=> 'je nepřítel',
			'IS_USER'			=> 'je uživatel',
			'IS_GROUP'		=> 'je ve skupině',
			'ANSWERED'		=> 'odpověď',
			'FORWARDED'		=> 'přeposlaná',
			'TO_GROUP'		=> 'pro mojí skupinu',
			'TO_ME'				=> 'pro mne',
	),


	'GROUPS_EXPLAIN'	=> 'Uživatelské skupiny umožňují administrátorům lépe spravovat uživatele. Každý uživatel má svojí výchozí skupinu. Ta definuje jak bude vypadat vůči ostatním uživatelům, například jakou bude mít barvu jména, avatar, hodnost, atd. Změnit výchozí skupinu lze pouze, pokud to administrátor na fóru povolí. Lze také vstoupit nebo být přidělen do dalších skupin. Některé skupiny vám mohou dát větší pravomoci pro prohlížení nebo zvýšit vaše možnosti v&nbsp;jiných oblastech.',
	'GROUP_LEADER'		=> 'Moderátor',
	'GROUP_MEMBER'		=> 'Člen',
	'GROUP_PENDING'		=> 'Čekající na přijetí',
	'GROUP_NONMEMBER'	=> 'Bez členství',
	'GROUP_DETAILS'		=> 'Detaily skupin',
	
	'NO_LEADER'			=> 'Žádná moderátorství skupin',
	'NO_MEMBER'			=> 'Žádná členství ve skupinách',
	'NO_PENDING'		=> 'Žádné čekající členství',
	'NO_NONMEMBER'	=> 'Žádné skupiny bez členství',
));

?>